@@ -7,6 +7,7 @@ use File::Slurp;
 use JSON::Path;
 use YAML::XS qw(Load);
 use Ixchel::functions::file_get;
+use base 'Ixchel::Actions::base';
 
 =head1 NAME
 
@@ -14,13 +15,19 @@ Ixchel::Actions::xeno - Invokes xeno_build with the specified hash.
 
 =head1 VERSION
 
-Version 0.2.0
+Version 0.3.0
 
 =cut
 
-our $VERSION = '0.2.0';
+our $VERSION = '0.3.0';
 
-=head1 SYNOPSIS
+=head1 CLI SYNOPSIS
+
+ixchel -a xeno B<--xb> <file>
+
+ixchel -a xeno B<-r> <repo item>
+
+=head1 CODE SYNOPSIS
 
     use Data::Dumper;
 
@@ -48,68 +55,21 @@ Install use the file from URL.
     .errors :: A array of errors encountered.
     .status_text :: A string description of what was done and the results.
     .ok :: Set to zero if any of the above errored.
+    .xeno_results :: Return from xeno_build.
 
 =cut
 
-sub new {
-	my ( $empty, %opts ) = @_;
+sub new_extra { }
 
-	my $self = {
-		config => {},
-		vars   => {},
-		arggv  => [],
-		opts   => {},
-	};
-	bless $self;
-
-	if ( defined( $opts{config} ) ) {
-		$self->{config} = $opts{config};
-	}
-
-	if ( defined( $opts{t} ) ) {
-		$self->{t} = $opts{t};
-	} else {
-		die('$opts{t} is undef');
-	}
-
-	if ( defined( $opts{share_dir} ) ) {
-		$self->{share_dir} = $opts{share_dir};
-	}
-
-	if ( defined( $opts{opts} ) ) {
-		$self->{opts} = \%{ $opts{opts} };
-	}
-
-	if ( defined( $opts{argv} ) ) {
-		$self->{argv} = $opts{argv};
-	}
-
-	if ( defined( $opts{vars} ) ) {
-		$self->{vars} = $opts{vars};
-	}
-
-	if ( defined( $opts{ixchel} ) ) {
-		$self->{ixchel} = $opts{ixchel};
-	}
-
-	return $self;
-} ## end sub new
-
-sub action {
+sub action_extra {
 	my $self = $_[0];
 
-	$self->{results} = {
-		errors      => [],
-		status_text => '',
-		ok          => 0,
-	};
-
 	# if neither are defined error and return
 	if ( !defined( $self->{opts}{xb} ) && !defined( $self->{opts}{r} ) && !defined( $self->{opts}{u} ) ) {
 		my $error = 'Neither --xb, -r, or -u specified';
 		warn($error);
 		push( @{ $self->{results}{errors} }, $error );
-		return $self->{results};
+		return undef;
 	}
 
 	# if neither are defined error and return
@@ -124,10 +84,8 @@ sub action {
 		$args_test++;
 	}
 	if ( $args_test >= 2 ) {
-		my $error = 'Neither --xb, -r, and/or  -u specified together... can only use one';
-		warn($error);
-		push( @{ $self->{results}{errors} }, $error );
-		return $self->{results};
+		$self->status_add( error => 1, status => '--xb, -r, and/or  -u specified together... can only use one' );
+		return undef;
 	}
 
 	my $xeno_build;
@@ -143,42 +101,42 @@ sub action {
 		}
 		eval { $xeno_build_raw = read_file($xeno_build_file) || die( 'Failed to read "' . $xeno_build_file . '"' ); };
 		if ($@) {
-			my $error = 'xeno_build errored: ' . $@;
-			warn($error);
-			push( @{ $self->{results}{errors} }, $error );
-			return $self->{results};
+			$self->status_add( error => 1, status => 'Reading the specified file failed ... ' . $@ );
+			return undef;
 		}
 	} elsif ( defined( $self->{opts}{r} ) ) {
 		$self->{opts}{r} =~ s/\.yaml$//;
 		my $url = 'https://raw.githubusercontent.com/LilithSec/xeno_build/main/' . $self->{opts}{r} . '.yaml';
 		eval { $xeno_build_raw = file_get( url => $url ); };
 		if ($@) {
-			my $error = 'xeno_build errored: ' . $@;
-			warn($error);
-			push( @{ $self->{results}{errors} }, $error );
-			return $self->{results};
+			$self->status_add(
+				error  => 1,
+				status => 'Fetching the specified item from the xeno_build repo failed ... ' . $@
+			);
+			return undef;
 		}
-	}elsif (defined($self->{opts}{u})) {
+	} elsif ( defined( $self->{opts}{u} ) ) {
 		eval { $xeno_build_raw = file_get( url => $self->{opts}{u} ); };
 		if ($@) {
-			my $error = 'xeno_build errored: ' . $@;
-			warn($error);
-			push( @{ $self->{results}{errors} }, $error );
-			return $self->{results};
+			$self->status_add( error => 1, status => 'Fetching the specified URL failed ... ' . $@ );
+			return undef;
 		}
-	} ## end elsif ( defined( $self->{opts}{r} ) )
+	}
 
 	# parse the xeno_build yaml
 	eval { $xeno_build = Load($xeno_build_raw); };
 	if ($@) {
-		my $error = 'xeno_build errored: ' . $@;
-		warn($error);
-		push( @{ $self->{results}{errors} }, $error );
-		return $self->{results};
+		$self->status_add( error => 1, status => 'Decoding xeno_build YAML failed ... ' . $@ );
+		return undef;
 	}
 
-	return $self->{ixchel}->action( action => 'xeno_build', opts => { xeno_build => $xeno_build } );
-} ## end sub action
+	eval {
+		$self->{results}{xeno_results}
+			= $self->{ixchel}->action( action => 'xeno_build', opts => { xeno_build => $xeno_build } );
+	};
+
+	return undef;
+} ## end sub action_extra
 
 sub short {
 	return 'Invoke xeno_build on the specified hash.';
